..  Copyright (C)  Brad Miller, David Ranum, Jeffrey Elkner, Peter Wentworth, Allen B. Downey, Chris
    Meyers, and Dario Mitchell.  Permission is granted to copy, distribute
    and/or modify this document under the terms of the GNU Free Documentation
    License, Version 1.3 or any later version published by the Free Software
    Foundation; with Invariant Sections being Forward, Prefaces, and
    Contributor List, no Front-Cover Texts, and no Back-Cover Texts.  A copy of
    the license is included in the section entitled "GNU Free Documentation
    License".

Variables, Expressions and Statements
=====================================


.. index:: value, data type, string, integer, int, float, class

.. index::
    single: triple quoted string

.. _values_n_types:

.. youtube:: vNfCfowr-pQ
    :divid: typesnconvert
    :height: 315
    :width: 560
    :align: left

In order to get started learning any programming language there are a number of
concepts and ideas that are necessary.
The goal of this chapter is to introduce you to the basic vocabulary of programming and some of the fundamental
building blocks of Python.
